;;; tdbsf-db-file-faces.el --- faces for the TDBSF in Database File mode

;; Copyright (c) 2001 Florent Rougon

;; Maintainer: Florent Rougon <flo@via.ecp.fr>

;; This file is part of TDBSF.

;; TDBSF is free software; you can redistribute it and/or modify it
;; under the terms of the GNU General Public License as published by
;; the Free Software Foundation; either version 2, or (at your option)
;; any later version.

;; TDBSF is distributed in the hope that it will be useful, but
;; WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
;; General Public License for more details.

;; You should have received a copy of the GNU General Public License
;; along with TDBSF; see the file COPYING. If not, write to the Free
;; Software Foundation, Inc., 59 Temple Place - Suite 330,
;; Boston, MA 02111-1307, USA.

;;; Code:

(defvar tdbsf-db-file-and-faces-count 10
  "Number of faces used to display matches of terms being arguments of &
operators.

If a search expression, after tree optimization, lead to a node like this:

    foo & bar & quux      (think of it as &(foo, bar, quux) to see a node)

and if this part was used to determine that a record matched (I mean: if the
search expression contains nodes like (A | B), B can be true but not used to
determine that the record matches, if A is also true), then \"foo\", \"bar\"
and \"quux\" will be covered by an overlay giving them the same face.

This face will have a name of the form \"tdbsf-db-file-and-face-xyz\", where
xyz is an integer between 1 and `tdbsf-db-file-and-faces-count'.

Several such &-expressions will each get a different face (by assigning a
different xyz to each &-expression), unless you have more than
`tdbsf-db-file-and-faces-count' &-expression matches within the same record
that were not aggregated with one another during the tree optimization.

Note: if an argument of an &-expression is not a simple regular expression,
the way to fontify it is not straightforward. For instance, with the
expression:

    foo & bar & !quux

it is impossible to fontify \"!quux\": if the whole &-expression matches in,
there is no match for \"quux\".")

(defface tdbsf-db-file-and-face-1
  '((
     ((class color))
     (:foreground "blue"))
    (t (:inverse-video t))              ; not tested
    )
  "Used to display a &-type match in tdbsf-db-file-mode.")

(defface tdbsf-db-file-and-face-2
  '((
     ((class color))
     (:foreground "green"))
    (t (:inverse-video t))              ; not tested
    )
  "Used to display a &-type match in tdbsf-db-file-mode.")

(defface tdbsf-db-file-and-face-3
  '((
     ((class color))
     (:foreground "khaki"))
    (t (:inverse-video t))              ; not tested
    )
  "Used to display a &-type match in tdbsf-db-file-mode.")

(defface tdbsf-db-file-and-face-4
  '((
     ((class color))
     (:foreground "indian red"))
    (t (:inverse-video t))              ; not tested
    )
  "Used to display a &-type match in tdbsf-db-file-mode.")

(defface tdbsf-db-file-and-face-5
  '((
     ((class color))
     (:foreground "yellow"))
    (t (:inverse-video t))              ; not tested
    )
  "Used to display a &-type match in tdbsf-db-file-mode.")

(defface tdbsf-db-file-and-face-6
  '((
     ((class color))
     (:foreground "red"))
    (t (:inverse-video t))              ; not tested
    )
  "Used to display a &-type match in tdbsf-db-file-mode.")

(defface tdbsf-db-file-and-face-7
  '((
     ((class color))
     (:foreground "magenta"))
    (t (:inverse-video t))              ; not tested
    )
  "Used to display a &-type match in tdbsf-db-file-mode.")

(defface tdbsf-db-file-and-face-8
  '((
     ((class color))
     (:foreground "maroon"))
    (t (:inverse-video t))              ; not tested
    )
  "Used to display a &-type match in tdbsf-db-file-mode.")

(defface tdbsf-db-file-and-face-9
  '((
     ((class color))
     (:foreground "hot pink"))
    (t (:inverse-video t))              ; not tested
    )
  "Used to display a &-type match in tdbsf-db-file-mode.")

(defface tdbsf-db-file-and-face-10
  '((
     ((class color))
     (:foreground "cyan"))
    (t (:inverse-video t))              ; not tested
    )
  "Used to display a &-type match in tdbsf-db-file-mode.")


;;;; Faces for elements of a near expression

(defvar tdbsf-db-file-near-faces-count 10
  "Number of faces used to display matches of terms being elements of near
expressions.

A \"near expression\", or \"~-expression\", is a search expression part like
this:

    fo{2,} ~3 bar ~4 qu+x ~2 spam ~6 eggs

which matches if a match of \"fo{2,}\" is found within 3 words of an
occurrence of \"bar\", with _this_ occurrence of \"bar\" being within 4
words of a match of \"qu+x\", and so on.

\"fo{2,}\", \"bar\", \"qu+x\", \"spam\" and \"eggs\" are called the
\"elements\" of the near expression.

If a near expression was used to determine that a record matched (I mean: if
the search expression contains nodes like (A | B), B can be true but not
used to determine that the record matches, if A is also true), then all its
elements' matches will be covered by an overlay giving them the same face.

This face will have a name of the form \"tdbsf-db-file-near-face-xyz\",
where xyz is an integer between 1 and `tdbsf-db-file-near-faces-count'.

Several such ~-expressions will each get a different face (by assigning a
different xyz to each &-expression), unless you have more than
`tdbsf-db-file-near-faces-count' ~-expression matches within the same
record.")

(defface tdbsf-db-file-near-face-1
  '((
     ((class color))
     (:background "moccasin"))
    (t (:inverse-video t))              ; not tested
    )
  "Used to display a ~-type match in tdbsf-db-file-mode.")

(defface tdbsf-db-file-near-face-2
  '((
     ((class color))
     (:background "lavender"))
    (t (:inverse-video t))              ; not tested
    )
  "Used to display a ~-type match in tdbsf-db-file-mode.")

(defface tdbsf-db-file-near-face-3
  '((
     ((class color))
     (:background "lemon chiffon"))
    (t (:inverse-video t))              ; not tested
    )
  "Used to display a ~-type match in tdbsf-db-file-mode.")

(defface tdbsf-db-file-near-face-4
  '((
     ((class color))
     (:background "misty rose"))
    (t (:inverse-video t))              ; not tested
    )
  "Used to display a ~-type match in tdbsf-db-file-mode.")

(defface tdbsf-db-file-near-face-5
  '((
     ((class color))
     (:background "light slate gray"))
    (t (:inverse-video t))              ; not tested
    )
  "Used to display a ~-type match in tdbsf-db-file-mode.")

(defface tdbsf-db-file-near-face-6
  '((
     ((class color))
     (:background "light grey"))
    (t (:inverse-video t))              ; not tested
    )
  "Used to display a ~-type match in tdbsf-db-file-mode.")

(defface tdbsf-db-file-near-face-7
  '((
     ((class color))
     (:background "cornflower blue"))
    (t (:inverse-video t))              ; not tested
    )
  "Used to display a ~-type match in tdbsf-db-file-mode.")

(defface tdbsf-db-file-near-face-8
  '((
     ((class color))
     (:background "aquamarine"))
    (t (:inverse-video t))              ; not tested
    )
  "Used to display a ~-type match in tdbsf-db-file-mode.")

(defface tdbsf-db-file-near-face-9
  '((
     ((class color))
     (:background "pale green"))
    (t (:inverse-video t))              ; not tested
    )
  "Used to display a ~-type match in tdbsf-db-file-mode.")

(defface tdbsf-db-file-near-face-10
  '((
     ((class color))
     (:background "yellow"))
    (t (:inverse-video t))              ; not tested
    )
  "Used to display a ~-type match in tdbsf-db-file-mode.")

(provide 'tdbsf-db-file-faces)
