# Macro for substituting automake variables in arbitrary files. Using
# AC_CONFIG_FILES would be easier, but the GNU standards recommend to perform
# substitutions containing $prefix (or similar variables) at Make time instead
# of configure time, because this allows users to call
# 'make install prefix=/foo/bar' without any need to reconfigure or rebuild.
#
# cf. http://www.gnu.org/software/automake/manual/automake.html#Scripts and
# http://www.gnu.org/software/automake/manual/autoconf.html#Installation-Directory-Variables
#
# This macro inserts a warning with $(1) as the comment char after the first
# $(2) lines of the input file [stdin] (at the beginning of the file if only
# one parameter is given).
do_subst = { { n=$(if $(strip $(2)),$(2),0); \
               head -n $$n; \
               echo "$(1) Warning! This is an automatically generated file."; \
               echo "$(1) Edit the corresponding .in file instead."; \
               echo "$(1)"; \
               cat; } \
             | sed \
        -e 's|@PACKAGE[@]|$(PACKAGE)|g' \
        -e 's|@VERSION[@]|$(VERSION)|g' \
        -e 's|@prefix[@]|$(prefix)|g' \
        -e 's|@bindir[@]|$(bindir)|g' \
        -e 's|@pkgdatadir[@]|$(pkgdatadir)|g' \
        -e 's|@pythondir[@]|$(pythondir)|g' \
        -e 's|@pkgpythondir[@]|$(pkgpythondir)|g'; }
